aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/compiler/csharp_generator.cc
diff options
context:
space:
mode:
authorGravatar Jan Tattermusch <jtattermusch@google.com>2015-08-05 14:54:08 -0700
committerGravatar Jan Tattermusch <jtattermusch@google.com>2015-08-05 14:54:08 -0700
commite5e57adf71fd65fb400ab0cbe94766b47a46baa8 (patch)
tree04aaabc16d6c971794bf1a4dfb12f5bb96d5b1b6 /src/compiler/csharp_generator.cc
parent5cb5ceda2c146c165253160e969b7f04469dd81c (diff)
update generator
Diffstat (limited to 'src/compiler/csharp_generator.cc')
-rw-r--r--src/compiler/csharp_generator.cc24
1 files changed, 12 insertions, 12 deletions
diff --git a/src/compiler/csharp_generator.cc b/src/compiler/csharp_generator.cc
index c9706e13ca..9432bdda96 100644
--- a/src/compiler/csharp_generator.cc
+++ b/src/compiler/csharp_generator.cc
@@ -276,9 +276,9 @@ void GenerateClientInterface(Printer* out, const ServiceDescriptor *service) {
GetClassName(method->input_type()), "response",
GetClassName(method->output_type()));
// overload taking CallContext as a param
out->Print(
- "$response$ $methodname$($request$ request, CallContext context);\n",
+ "$response$ $methodname$($request$ request, CallOptions options);\n",
"methodname", method->name(), "request",
GetClassName(method->input_type()), "response",
GetClassName(method->output_type()));
@@ -294,9 +294,9 @@ void GenerateClientInterface(Printer* out, const ServiceDescriptor *service) {
GetMethodRequestParamMaybe(method), "returntype",
GetMethodReturnTypeClient(method));
// overload taking CallContext as a param
out->Print(
- "$returntype$ $methodname$($request_maybe$CallContext context);\n",
+ "$returntype$ $methodname$($request_maybe$CallOptions options);\n",
"methodname", method_name, "request_maybe",
GetMethodRequestParamMaybe(method), "returntype",
GetMethodReturnTypeClient(method));
@@ -356,21 +356,21 @@ void GenerateClientStub(Printer* out, const ServiceDescriptor *service) {
GetClassName(method->output_type()));
out->Print("{\n");
out->Indent();
- out->Print("var call = CreateCall($methodfield$, new CallContext(headers, deadline, cancellationToken));\n",
+ out->Print("var call = CreateCall($methodfield$, new CallOptions(headers, deadline, cancellationToken));\n",
"methodfield", GetMethodFieldName(method));
out->Print("return Calls.BlockingUnaryCall(call, request);\n");
out->Outdent();
out->Print("}\n");
// overload taking CallContext as a param
out->Print(
- "public $response$ $methodname$($request$ request, CallContext context)\n",
+ "public $response$ $methodname$($request$ request, CallOptions options)\n",
"methodname", method->name(), "request",
GetClassName(method->input_type()), "response",
GetClassName(method->output_type()));
out->Print("{\n");
out->Indent();
- out->Print("var call = CreateCall($methodfield$, context);\n",
+ out->Print("var call = CreateCall($methodfield$, options);\n",
"methodfield", GetMethodFieldName(method));
out->Print("return Calls.BlockingUnaryCall(call, request);\n");
out->Outdent();
@@ -388,7 +388,7 @@ void GenerateClientStub(Printer* out, const ServiceDescriptor *service) {
GetMethodReturnTypeClient(method));
out->Print("{\n");
out->Indent();
- out->Print("var call = CreateCall($methodfield$, new CallContext(headers, deadline, cancellationToken));\n",
+ out->Print("var call = CreateCall($methodfield$, new CallOptions(headers, deadline, cancellationToken));\n",
"methodfield", GetMethodFieldName(method));
switch (GetMethodType(method)) {
case METHODTYPE_NO_STREAMING:
@@ -410,15 +410,15 @@ void GenerateClientStub(Printer* out, const ServiceDescriptor *service) {
out->Outdent();
out->Print("}\n");
// overload taking CallContext as a param
out->Print(
- "public $returntype$ $methodname$($request_maybe$CallContext context)\n",
+ "public $returntype$ $methodname$($request_maybe$CallOptions options)\n",
"methodname", method_name, "request_maybe",
GetMethodRequestParamMaybe(method), "returntype",
GetMethodReturnTypeClient(method));
out->Print("{\n");
out->Indent();
- out->Print("var call = CreateCall($methodfield$, context);\n",
+ out->Print("var call = CreateCall($methodfield$, options);\n",
"methodfield", GetMethodFieldName(method));
switch (GetMethodType(method)) {
case METHODTYPE_NO_STREAMING:
@@ -276,9 +276,9 @@ void GenerateClientInterface(Printer* out, const ServiceDescriptor *service) {
GetClassName(method->input_type()), "response",
GetClassName(method->output_type()));
- // overload taking CallContext as a param
+ // overload taking CallOptions as a param
out->Print(
@@ -294,9 +294,9 @@ void GenerateClientInterface(Printer* out, const ServiceDescriptor *service) {
GetMethodRequestParamMaybe(method), "returntype",
GetMethodReturnTypeClient(method));
- // overload taking CallContext as a param
+ // overload taking CallOptions as a param
out->Print(
@@ -356,21 +356,21 @@ void GenerateClientStub(Printer* out, const ServiceDescriptor *service) {
out->Outdent();
out->Print("}\n");
- // overload taking CallContext as a param
+ // overload taking CallOptions as a param
out->Print(
@@ -410,15 +410,15 @@ void GenerateClientStub(Printer* out, const ServiceDescriptor *service) {
out->Outdent();
out->Print("}\n");
- // overload taking CallContext as a param
+ // overload taking CallOptions as a param
out->Print(